@@ -1,6 +1,6 @@
 package DBIx::Class::LookupColumn;
 {
-  $DBIx::Class::LookupColumn::VERSION = '0.01';
+  $DBIx::Class::LookupColumn::VERSION = '0.02';
 }
 use base DBIx::Class::LookupColumn::LookupColumnComponent;
 
@@ -11,7 +11,7 @@ DBIx::Class::LookupColumn - DBIx::Class components to help using Lookup tables.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -85,6 +85,67 @@ Using this module solved this problem, and we hope it could be useful to others.
 
 Do not use this module on I<big> tables, it could actually slow down your code and eat all your memory.
 
+
+=head1 Example of use in a many-to-many relationship
+
+Suppose we have a many-to-many relationship between the B<Actor> and B<RoleType> tables. Then a new table, let's call it
+B<ActorRole>, has to be designed for playing the interface between them.
+In this case the RoleType is the Lookup table and ActorRole the one the lookup relation is called on.
+
+ # In the Actor ResultSource
+ # let's add both functions below as suggar
+ sub role_names {
+ 	my $self = shift;
+ 	# role() is generated by DBIx::Class::LookupColumn::LookupColumnComponent
+	return map { $_->role() } $self->actorroles;
+ };
+
+ sub has_role {
+	my ( $self, $role_name ) = @_;
+	# is_role() is generated by DBIx::Class::LookupColumn::LookupColumnComponent
+	my $found = grep { $_->is_role( $role_name ) }  $self->actorroles;
+	return $found;
+ }
+
+ # In the appropriated ResultSource
+ # let's define the relationships
+ SchemaMany2Many::Result::Actor->has_many('actorroles', 'SchemaMany2Many::Result::ActorRole', { 'foreign.actor_id' => 'self.actor_id' } );
+ SchemaMany2Many::Result::Actor->many_to_many('roletypes',  'actorroles', 'roletype');
+
+ SchemaMany2Many::Result::ActorRole->belongs_to('roletype', 'SchemaMany2Many::Result::RoleType', {"foreign.role_id" => "self.role_id" } );
+ SchemaMany2Many::Result::ActorRole->belongs_to('actor',  'SchemaMany2Many::Result::Actor', {"foreign.actor_id" => "self.actor_id" });
+
+ SchemaMany2Many::Result::RoleType->has_many('actorroles', 'SchemaMany2Many::Result::ActorRole', { 'foreign.role_id' => 'self.role_id' } );
+ SchemaMany2Many::Result::RoleType->many_to_many('actors', 'actorroles', 'actor');
+
+ # In the Schema Class
+ # let's automatize the lookup relation creation
+ SchemaMany2Many->load_components( qw/LookupColumn::Auto/ );
+
+ my @tables = $schema->sources;
+ SchemaMany2Many->add_lookups(
+		targets => [ grep{ !/Type$/  } @tables ],
+		lookups => [ grep{ /Type$/} @tables],
+		relation_name_builder => sub{
+			my ( $class, %args) = @_;	
+			$args{lookup} =~ /^(.+)Type$/;
+			lc( $1 );
+		},
+		lookup_field_name_builder => sub { 'name' }
+ );
+
+ # In a script
+ my $actor = $schema->resultset('Actor')->find ( 1 );
+ my @roles_played = $actor->role_names();
+
+ $actor->has_role ('Warlock');  # returns boolean
+ # $actor->has_role ('Warloc');  # throws an exception because does not exist in the DB
+
+ # inefficient classical way to do it
+ my @roles_played_classical = map { $_->roletype()->name } $actor->actorroles(); # does a DB request at EACH loop !
+ my $played_warlock =  'Warlock' ~~ @roles_played_classical; # assigns boolean 
+ # my $played_warloc =  'Warloc' ~~ @roles_played; # assigns an empty string, NOT safe regarding TYPOS !
+
 =cut
 
 1; # End of DBIx::Class::LookupColumn
